@@ -7,6 +7,7 @@ from functools import wraps
 
 import numpy as np
 
+from .__init__ import __version__ as PYMBD_VERSION
 from .pymbd import _array, from_volumes
 
 try:
@@ -22,6 +23,20 @@ with_mpi = _lib.cmbd_with_mpi
 with_scalapack = _lib.cmbd_with_scalapack
 """Whether Libmbd was compiled with Scalapack"""
 
+LIBMBD_VERSION = (
+    _lib.cmbd_version_major,
+    _lib.cmbd_version_minor,
+    _lib.cmbd_version_patch,
+)
+
+# do not test versions when running autodoc
+if PYMBD_VERSION and isinstance(LIBMBD_VERSION[0], int):
+    assert PYMBD_VERSION[0] == LIBMBD_VERSION[0]
+    if PYMBD_VERSION[0] == 0:
+        assert PYMBD_VERSION[1] == LIBMBD_VERSION[1]
+    else:
+        assert PYMBD_VERSION[1] <= LIBMBD_VERSION[1]
+
 if with_mpi:
     from mpi4py import MPI  # noqa
 
@@ -165,9 +180,10 @@ class MBDGeom(object):
         self,
         alpha_0,
         C6,
-        R_vdw,
-        beta,
+        R_vdw=None,
+        beta=0.0,
         a=6.0,
+        sigma=None,
         damping='fermi,dip',
         variant='rsscs',
         force=False,
@@ -177,16 +193,22 @@ class MBDGeom(object):
         :param array-like alpha_0: (a.u.) atomic polarizabilities
         :param array-like C6: (a.u.) atomic :math:`C_6` coefficients
         :param array-like R_vdw: (a.u.) atomic vdW radii
+        :param array-like sigma: (a.u.) oscillator widths
         :param float beta: MBD damping parameter :math:`\beta`
         :param float a: MBD damping parameter :math:`a`
         :param damping str: type of damping
         :param variant str: one of 'plain', 'scs', 'rsscs'
         :param force bool: if True, calculate energy gradients
         """
-        alpha_0, C6, R_vdw = map(_array, (alpha_0, C6, R_vdw))
+        alpha_0, C6, R_vdw, sigma = map(_array, (alpha_0, C6, R_vdw, sigma))
         n_atoms = len(self)
         damping_f = _lib.cmbd_init_damping(
-            n_atoms, damping.encode(), _cast('double*', R_vdw), _ffi.NULL, beta, a
+            n_atoms,
+            damping.encode(),
+            _cast('double*', R_vdw),
+            _cast('double*', sigma),
+            beta,
+            a,
         )
         args = (
             self._geom_f,
